From 8436a56dd80be12109ea2743c88bc13fa8e9dde0 Mon Sep 17 00:00:00 2001
From: Francois-Rene Rideau <tunes@google.com>
Date: Tue, 8 Oct 2013 18:31:43 -0400
Subject: [PATCH] Use the normalized name UIOP instead of asdf-driver in the
 tests.

---
 test/asdf-pathname-test.script | 2 +-
 test/hello-world-example.asd   | 2 +-
 test/hello.lisp                | 2 +-
 test/make-hello-world.lisp     | 4 ++--
 test/script-support.lisp       | 6 +++---
 test/unintern-foo.lisp         | 2 +-
 6 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/test/asdf-pathname-test.script b/test/asdf-pathname-test.script
index edab2e58..c6a67918 100644
--- a/test/asdf-pathname-test.script
+++ b/test/asdf-pathname-test.script
@@ -1,6 +1,6 @@
 ;;; -*- Lisp -*-
 
-(defpackage :asdf-pathname-test (:use :asdf :asdf/driver :asdf/common-lisp :asdf/cache :asdf-test))
+(defpackage :asdf-pathname-test (:use :asdf :uiop :uiop/common-lisp :asdf/cache :asdf-test))
 (in-package :asdf-pathname-test)
 
 ;;(setf *unspecific-pathname-type* nil)
diff --git a/test/hello-world-example.asd b/test/hello-world-example.asd
index 72190c2c..c1c5eaad 100644
--- a/test/hello-world-example.asd
+++ b/test/hello-world-example.asd
@@ -3,5 +3,5 @@
 (defsystem :hello-world-example
   :build-operation program-op
   :entry-point "hello:entry-point"
-  :depends-on (:asdf-driver)
+  :depends-on (:uiop)
   :components ((:file "hello")))
diff --git a/test/hello.lisp b/test/hello.lisp
index 5ffca84b..f50a3ad8 100644
--- a/test/hello.lisp
+++ b/test/hello.lisp
@@ -1,5 +1,5 @@
 (defpackage :hello
-  (:use :cl :asdf/driver)
+  (:use :cl :uiop)
   (:export #:main #:entry-point))
 
 (in-package :hello)
diff --git a/test/make-hello-world.lisp b/test/make-hello-world.lisp
index c939b51b..a51f7fac 100644
--- a/test/make-hello-world.lisp
+++ b/test/make-hello-world.lisp
@@ -4,14 +4,14 @@
 (load-asdf)
 #+ecl (require :cmp)
 
-(asdf-test::register-directory asdf-test::*asdf-directory*) ;; we need asdf-driver, and ECL can dump.
+(asdf-test::register-directory asdf-test::*asdf-directory*) ;; we need UIOP, and ECL can dump.
 (asdf-test::register-directory asdf-test::*uiop-directory*)
 (asdf:upgrade-asdf) ;; may recompile and rename away package asdf?
 
 (asdf-test::frob-packages)
 
 (with-test ()
-  ;;(dolist (s '(:asdf :asdf/driver :asdf/defsystem :uiop)) (DBG :foo s (asdf::builtin-system-p (find-system s))))
+  ;;(dolist (s '(:asdf :uiop :asdf/defsystem :uiop)) (DBG :foo s (asdf::builtin-system-p (find-system s))))
   ;;(trace perform-plan perform)
   (operate 'load-fasl-op :hello-world-example)
   (operate 'program-op :hello-world-example))
diff --git a/test/unintern-foo.lisp b/test/unintern-foo.lisp
index d2604a77..e05dc2a7 100644
--- a/test/unintern-foo.lisp
+++ b/test/unintern-foo.lisp
@@ -2,4 +2,4 @@
   (when (find-package :asdf-test/deferred-warnings)
     (delete-package :asdf-test/deferred-warnings)))
 
-(defpackage :asdf-test/deferred-warnings (:use :asdf/driver :asdf/common-lisp))
+(defpackage :asdf-test/deferred-warnings (:use :uiop :uiop/common-lisp))
diff --git a/test/script-support.lisp b/test/script-support.lisp
index df7b8bab..07f041fd 100644
--- a/test/script-support.lisp
+++ b/test/script-support.lisp
@@ -6,7 +6,7 @@ Some constraints:
  But we *can* rely on ASDF being present *after* we load it.
 * evaluating this file MUST NOT print anything,
  because we use it in the forward-ref test to check that nothing is printed.
 * We make sure that none of our symbols clash with asdf/driver or asdf,
  so we may use-package them during testing.
 |#
 
@@ -320,7 +320,7 @@ is bound, write a message and exit on an error.  If
   (verbose t nil)
   (loop :for file :in files :do
     (load (string-downcase file)))
-  (setf *package* (some 'find-package '(:asdf :asdf/driver :asdf/utility :asdf/package :asdf-test)))
+  (setf *package* (some 'find-package '(:asdf :uiop :asdf/utility :asdf/package :asdf-test)))
   (load "contrib/debug.lisp"))
 
 (defun load-asdf-lisp (&optional tag)
@@ -520,7 +520,7 @@ is bound, write a message and exit on an error.  If
 (defun frob-packages ()
   (format t "Frob packages~%")
   (use-package :asdf :asdf-test)
-  (when (find-package :asdf/driver) (use-package :asdf/driver :asdf-test))
+  (when (find-package :uiop) (use-package :uiop :asdf-test))
   (when (find-package :asdf/cache) (use-package :asdf/cache :asdf-test))
   (setf *package* (find-package :asdf-test))
   t)
@@ -6,7 +6,7 @@ Some constraints:
 * evaluating this file MUST NOT print anything,
  because we use it in the forward-ref test to check that nothing is printed.
-* We make sure that none of our symbols clash with asdf/driver or asdf,
+* We make sure that none of our symbols clash with uiop or asdf,
  so we may use-package them during testing.
 |#
-- 
GitLab